version = "0.1.1"


def hello():
    print('Hello from Dockme in Version:', version)


def get_version():
    print('Version:', version)



from .get_image import get_image
from .run_container import run_container
from .stop_container import stop_container
from .delet_container import delet_container
from .delet_image import delet_image
from. run_command_in_con import run_command



__all__ = ['get_image', 'run_container', 'stop_container', 'delet_container', 'delet_image', 'run_command']


import os


def run_container(container_name, ports, image):
    try:
        if ports == None:
            os.system('docker run -it -d --name ' + container_name + ' ' + image)
        else:
            
           os.system('docker run -it -d -p ' + ports + ' --name ' + container_name + ' ' + image)
    except:
        print("Could not execute command")


import os


def run_command(container_name, command):
    try:
        os.system('docker exec -it -d', container_name, ' bash')
        os.system(command)
        os.system('exit')
    except:
        print("Could not execute command")